function obj=zeros(varargin)
% FUNCTION fc_amat.zeros
% -- zeros([N,m,n]) or zeros([N,m,n],classname)
% -- zeros(N,m,n) or zeros(N,m,n,classname)
%      Return an N-by-m-by-n amat object where each of its N matrices are the 
%      m-by-n matrix whose elements are all 0.
%
% -- zeros(N,m) or zeros(N,m,classname)
%      Return an N-by-m-by-m amat object where each of its N matrices are the 
%      m-by-m matrix whose elements are all 0.
%    
%      Optional classname argument can be used for setting amat object data 
%      type (default 'double').
%
%      See also: fc_amat.ones, fc_amat.eye, 
%                fc_amat.random.rand, fc_amat.random.randn
%
  classname='double';
  assert( ismember(nargin,[1,2,3,4]) )
  n=nargin;
  if ischar(varargin{end})
    classname=varargin{end};
    n=n-1;
  end
  switch n
    case 1 % varargin={[N,m,n]} or varargin={[N,m,n],classname}
      S=varargin{1}; assert(length(S)==3)
      N=S(1);m=S(2);n=S(3);
    case 2 % varargin={N,m} or % varargin={N,m,classname}
        N=varargin{1};m=varargin{2};n=m;
    case 3  % varargin={N,m,n} or % varargin={N,m,n,classname}
      N=varargin{1};
      m=varargin{2};
      n=varargin{3};
  end
  obj=amat(zeros(N,m,n,classname));
end
